@@ -74,6 +74,13 @@ static void _dumpIcaltime( const icaltimetype& t)
 */
 
 //@cond PRIVATE
+static QString quoteForParam( const QString &text )
+{
+  QString tmp = text;
+  tmp.remove( '"' );
+  return QString::fromLatin1( "\"" ) + tmp + QString::fromLatin1( "\"" );
+}
+
 const int gSecondsPerMinute = 60;
 const int gSecondsPerHour   = gSecondsPerMinute * 60;
 const int gSecondsPerDay    = gSecondsPerHour   * 24;
@@ -589,8 +596,7 @@ void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
   // comments
   QStringList comments = incidenceBase->comments();
   for ( QStringList::Iterator it = comments.begin(); it != comments.end(); ++it ) {
-    icalcomponent_add_property(
-      parent, icalproperty_new_comment( (*it).toUtf8() ) );
+    icalcomponent_add_property( parent, icalproperty_new_comment( (*it).toUtf8() ) );
   }
 
   // custom properties
@@ -616,7 +622,7 @@ icalproperty *ICalFormatImpl::writeOrganizer( const Person &organizer )
 
   if ( !organizer.name().isEmpty() ) {
     icalproperty_add_parameter(
-      p, icalparameter_new_cn( organizer.name().toUtf8() ) );
+      p, icalparameter_new_cn( quoteForParam( organizer.name() ).toUtf8() ) );
   }
   // TODO: Write dir, sent-by and language
 
@@ -657,7 +663,7 @@ icalproperty *ICalFormatImpl::writeAttendee( Attendee *attendee )
 
   if ( !attendee->name().isEmpty() ) {
     icalproperty_add_parameter(
-      p, icalparameter_new_cn( attendee->name().toUtf8() ) );
+      p, icalparameter_new_cn( quoteForParam( attendee->name() ).toUtf8() ) );
   }
 
   icalproperty_add_parameter(
@@ -935,7 +941,7 @@ icalcomponent *ICalFormatImpl::writeAlarm( Alarm *alarm )
         "MAILTO:" + (*ad).email().toUtf8() );
       if ( !(*ad).name().isEmpty() ) {
         icalproperty_add_parameter(
-          p, icalparameter_new_cn( (*ad).name().toUtf8() ) );
+          p, icalparameter_new_cn( quoteForParam( (*ad).name() ).toUtf8() ) );
       }
       icalcomponent_add_property( a, p );
     }
@@ -1022,13 +1028,9 @@ Todo *ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist )
     case ICAL_DUE_PROPERTY:
     { // due date/time
       KDateTime kdt = readICalDateTimeProperty( p, tzlist );
-      if ( kdt.isDateOnly() ) {
-        todo->setDtDue( KDateTime( kdt.date(), todo->dtStart().timeSpec() ), true );
-      } else {
-        todo->setDtDue( kdt, true );
-        todo->setAllDay( false );
-      }
+      todo->setDtDue( kdt, true );
       todo->setHasDueDate( true );
+      todo->setAllDay( kdt.isDateOnly() );
       break;
     }
     case ICAL_COMPLETED_PROPERTY:  // completion date/time
@@ -1213,6 +1215,12 @@ Journal *ICalFormatImpl::readJournal( icalcomponent *vjournal,
 
 Attendee *ICalFormatImpl::readAttendee( icalproperty *attendee )
 {
+  // the following is a hack to support broken calendars (like WebCalendar 1.0.x)
+  // that include non-RFC-compliant attendees.  Otherwise libical 0.42 asserts.
+  if ( !icalproperty_get_value( attendee ) ) {
+    return 0;
+  }
+
   icalparameter *p = 0;
 
   QString email = QString::fromUtf8( icalproperty_get_attendee( attendee ) );
@@ -1344,7 +1352,7 @@ Attachment *ICalFormatImpl::readAttachment( icalproperty *attach )
   case ICAL_ATTACH_VALUE:
   {
     icalattach *a = icalproperty_get_attach( attach );
-    if ( icalattach_get_is_url( a ) == 0 ) {
+    if ( !icalattach_get_is_url( a ) ) {
       p = (const char *)icalattach_get_data( a );
       if ( p ) {
         attachment = new Attachment( p );
@@ -1871,21 +1879,24 @@ void ICalFormatImpl::readAlarm( icalcomponent *alarm,
     case ICAL_TRIGGER_PROPERTY:
     {
       icaltriggertype trigger = icalproperty_get_trigger( p );
-      if ( icaltime_is_null_time( trigger.time ) ) {
-        if ( icaldurationtype_is_null_duration( trigger.duration ) ) {
-          kDebug() << "Trigger has no time and no duration.";
-        } else {
+      if ( !icaltime_is_null_time( trigger.time ) ) {
+        //set the trigger to a specific time (which is not in rfc2445, btw)
+        ialarm->setTime( readICalUtcDateTime( p, trigger.time, tzlist ) );
+      } else {
+        //set the trigger to an offset from the incidence start or end time.
+        if ( !icaldurationtype_is_bad_duration( trigger.duration ) ) {
           Duration duration( readICalDuration( trigger.duration ) );
           icalparameter *param =
             icalproperty_get_first_parameter( p, ICAL_RELATED_PARAMETER );
           if ( param && icalparameter_get_related( param ) == ICAL_RELATED_END ) {
-            ialarm->setEndOffset(duration);
+            ialarm->setEndOffset( duration );
           } else {
             ialarm->setStartOffset( duration );
           }
+        } else {
+          // a bad duration was encountered, just set a 0 duration from start
+          ialarm->setStartOffset( Duration( 0 ) );
         }
-      } else {
-        ialarm->setTime( readICalUtcDateTime( p, trigger.time, tzlist ) );
       }
       break;
     }
@@ -1899,9 +1910,8 @@ void ICalFormatImpl::readAlarm( icalcomponent *alarm,
       ialarm->setRepeatCount( icalproperty_get_repeat( p ) );
       break;
 
-      // Only in DISPLAY and EMAIL and PROCEDURE alarms
     case ICAL_DESCRIPTION_PROPERTY:
-    {
+    { // Only in DISPLAY and EMAIL and PROCEDURE alarms
       QString description = QString::fromUtf8( icalproperty_get_description( p ) );
       switch ( action ) {
       case ICAL_ACTION_DISPLAY:
@@ -2229,8 +2239,8 @@ icaldurationtype ICalFormatImpl::writeICalDuration( const Duration &duration )
     } else {
       d.weeks = 0;
       d.days  = value;
-      d.hours = d.minutes = d.seconds = 0;
     }
+    d.hours = d.minutes = d.seconds = 0;
   } else {
     if ( !( value % gSecondsPerWeek ) ) {
       d.weeks = value / gSecondsPerWeek;
