@@ -232,12 +232,10 @@ bool kio_sieveProtocol::parseCapabilities(bool requestCapabilities/* = false*/)
 				ksDebug << "Unknown action " << r.getAction() << "." << endl;
 
 		} else if (r.getKey() == "IMPLEMENTATION") {
-			if (r.getVal().toLower().contains("sieve") ) {
-				ksDebug << "Connected to Sieve server: " << r.getVal() << endl;
-				ret = true;
-				setMetaData("implementation", r.getVal());
-				m_implementation = r.getVal();
-			}
+			ksDebug << "Connected to Sieve server: " << r.getVal() << endl;
+			ret = true;
+			setMetaData("implementation", r.getVal());
+			m_implementation = r.getVal();
 
 		} else if (r.getKey() == "SASL") {
 			// Save list of available SASL methods
@@ -891,7 +889,10 @@ bool kio_sieveProtocol::saslInteract( void *in, AuthInfo &ai )
 
 			if (m_sUser.isEmpty() || m_sPass.isEmpty()) {
 				if (!openPasswordDialog(ai)) {
-					error(ERR_ABORTED, i18n("No authentication details supplied."));
+				  // calling error() below is wrong for two reasons:
+				  // - ERR_ABORTED is too harsh
+				  // - higher layers already call error() and that can't happen twice.
+					//error(ERR_ABORTED, i18n("No authentication details supplied."));
 					return false;
 				}
 				m_sUser = ai.username;
