@@ -127,7 +127,7 @@ void SmtpJob::startSmtpJob()
   KUrl destination;
   destination.setProtocol( ( transport()->encryption() == Transport::EnumEncryption::SSL ) ?
                            SMTPS_PROTOCOL : SMTP_PROTOCOL );
-  destination.setHost( transport()->host() );
+  destination.setHost( transport()->host().trimmed() );
   destination.setPort( transport()->port() );
 
   destination.addQueryItem( QLatin1String( "headers" ), QLatin1String( "0" ) );
@@ -164,7 +164,7 @@ void SmtpJob::startSmtpJob()
 #warning yet another KMail specific thing
 #endif
 //       KCursorSaver idle( KBusyPtr::idle() );
-      bool keep = true;
+      bool keep = transport()->storePassword();
       result = KIO::PasswordDialog::getNameAndPassword(
         user, passwd, &keep,
         i18n( "You need to supply a username and a password to use this SMTP server." ),
